@@ -5,7 +5,12 @@ from typing import *
 
 from cognite.seismic._api.api import API
 from cognite.seismic._api.utility import get_exact_match_filter, get_identifier
-from cognite.seismic.data_classes.api_types import Survey, SurveyCoverageSource, SurveyGridTransformation
+from cognite.seismic.data_classes.api_types import (
+    Survey,
+    SurveyCoverageSource,
+    SurveyGridTransformation,
+    survey_grid_transformation_to_proto,
+)
 from cognite.seismic.data_classes.errors import SeismicServiceError
 from grpc import StatusCode
 
@@ -18,12 +23,14 @@ if not os.getenv("READ_THE_DOCS"):
         GeoJson,
         Geometry,
     )
-    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import SearchSpec
+    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import OptionalMap, SearchSpec
     from cognite.seismic.protos.v1.seismic_service_messages_pb2 import (
         CreateSurveyRequest,
         DeleteSurveyRequest,
+        EditSurveyRequest,
         SearchSurveysRequest,
     )
+    from google.protobuf.wrappers_pb2 import StringValue
 else:
     from cognite.seismic._api.shims import SearchSpec
 
@@ -244,8 +251,6 @@ class SurveyV1API(API):
         Returns:
             :py:class:`~cognite.seismic.data_classes.api_types.Survey`
         """
-        if name is None:
-            name = survey_name
 
         # Creating the custom coverage field
         if custom_coverage_wkt:
@@ -260,7 +265,7 @@ class SurveyV1API(API):
             metadata=metadata,
             external_id=ExternalId(external_id=external_id),
             crs=crs,
-            grid_transformation=grid_transformation,
+            grid_transformation=survey_grid_transformation_to_proto(grid_transformation),
             custom_coverage=coverage,
         )
 
@@ -310,25 +315,28 @@ class SurveyV1API(API):
 
     def edit(
         self,
-        id: Optional[str] = None,
-        survey_id: Optional[str] = None,
-        name: Optional[str] = None,
-        survey_name: Optional[str] = None,
-        metadata: dict = None,
+        id: Optional[int] = None,
         external_id: Optional[str] = None,
-        survey_external_id: Optional[str] = None,
+        metadata: dict = None,
+        new_external_id: Optional[str] = None,
         crs: Optional[str] = None,
         grid_transformation: Optional[SurveyGridTransformation] = None,
         custom_coverage_wkt: Optional[str] = None,
         custom_coverage_geojson: Optional[dict] = None,
         clear_custom_coverage: Optional[bool] = False,
+        name: Optional[str] = None,
     ):
         """Edit a survey
+        This method replaces fields in an existing survey identified by either its id or external_id.
+        Method parameters that are non-null will be used to replace the corresponding field in the survey
+        object. Null (unspecified) method parameters will not affect a change to the survey object.
 
         Args:
-            id (Optional[str]): id of the survey to edit.
-            name (Optional[str]): name of the survey to edit.
-            metadata (dict): metadata of the survey to edit.
+            id (Optional[int]): integer id of the survey to edit.
+            external_id (Optional[str]): external id of the survey to edit.
+                Either id or external_id must be specified.
+            metadata (dict): metadata to be used by the survey.
+            new_external_id (Optiona[str]): External id to be used by the survey.
             crs (Optional[str]): Coordinate reference system to be used by all
                                  members of this survey
             grid_transformation (Optional[SurveyGridTransformation]):
@@ -346,29 +354,43 @@ class SurveyV1API(API):
             clear_custom_coverage (Optional[bool]):
                 Set this to True to clear the custom coverage from this survey, so that coverage is
                 computed as a union of the coverage of the data sets included in the survey.
+            name (Optional[str]): new name for the survey.
 
         Returns:
-            EditSurveyResponse: id, name and metadata of the survey.
+            Survey: id, name and metadata of the survey.
 
         """
-        if id is None:
-            id = survey_id
-        if name is None:
-            name = survey_name
-        if external_id is None:
-            external_id = survey_external_id
-        return self.v0_survey_api.edit(
-            id,
-            name,
-            metadata,
-            external_id,
-            crs,
-            grid_transformation,
-            custom_coverage_wkt,
-            custom_coverage_geojson,
-            clear_custom_coverage,
+
+        survey = get_identifier(id, external_id)
+
+        if clear_custom_coverage and (custom_coverage_wkt or custom_coverage_geojson):
+            raise Exception("Provide a custom_coverage or set clear_custom_coverage, but not both")
+        if custom_coverage_wkt:
+            coverage = CustomSurveyCoverage(custom_coverage=Geometry(crs=crs, wkt=custom_coverage_wkt))
+        elif custom_coverage_geojson:
+            coverage = CustomSurveyCoverage(custom_coverage=Geometry(crs=crs, geo=GeoJson(json=custom_coverage_wkt)))
+        elif clear_custom_coverage:
+            coverage = CustomSurveyCoverage(no_custom_coverage=CustomSurveyCoverage.NoCustomCoverage())
+        else:
+            coverage = None
+
+        metadata_param = OptionalMap(data=metadata) if metadata else None
+        new_external_id_param = ExternalId(external_id=new_external_id) if new_external_id else None
+        crs_param = StringValue(value=crs) if crs else None
+        name_param = StringValue(value=name) if name else None
+
+        request = EditSurveyRequest(
+            survey=survey,
+            metadata=metadata_param,
+            external_id=new_external_id_param,
+            crs=crs_param,
+            grid_transformation=grid_transformation,
+            custom_coverage=coverage,
+            new_name=name_param,
         )
 
+        return Survey.from_proto_survey(self.query.EditSurvey(request))
+
     def delete(
         self,
         id: Optional[str] = None,
